/*
export function someAction (context) {
}
*/
import firebase from "firebase/app";
import "firebase/auth";

export function signInWithGoogle({ commit, dispatch }) {
  var google = new firebase.auth.GoogleAuthProvider();
  google.setCustomParameters({
    // Forces account selection even when one account
    // is available.
    prompt: "select_account"
  });
  google.addScope("profile");
  google.addScope("email");
  commit("updateStatus", "loading");
  firebase
    .auth()
    .signInWithRedirect(google)
    .then(function(result) {
      var token = result.credential.accessToken;
      var user = result.user;
      commit("updateUser", user);
      commit("updateError", null);
      commit("updateToken", token);
      commit("updateStatus", "success");
      dispatch("loadUserProfile", user);
    })
    .catch(function(error) {
      commit("updateError", error.message);
      commit("updateStatus", "error");
    });
}

export function signInAnonymously({ commit, dispatch, state }, nickname) {
  commit("updateNickname", nickname);
  firebase
    .auth()
    .signInAnonymously()
    .then(function(result) {
      // var token = result.credential.accessToken;
      var user = result.user;
      commit("updateUser", { user, displayName: nickname });
      commit("updateError", null);
      dispatch("loadUserProfile", user);

      // dispatch("loadAnonymousProfile", { user, nickname });
    })
    .catch(function(error) {
      commit("updateError", error.message);
      commit("updateStatus", "error");
    });
}

export function loadUserProfile({ commit, dispatch, state }, payload) {
  commit("updateStatus", "loading");
  const db = firebase.firestore();
  const userRef = db.collection("users").doc(payload.uid);
  userRef
    .get()
    .then(function(doc) {
      const _setRef = () => {
        dispatch(
          "user/setUserRef",
          {
            ref: userRef
          },
          {
            root: true
          }
        )
          .then(function() {
            commit("updateStatus", "success");
          })
          .catch(function(error) {
            commit("updateStatus", "error");
            commit("updateError", error.message);
          });
      };

      if (doc.exists) {
        // console.log('Load user profile')
        // console.log(doc)
        commit("updateUserProfile", doc.data());
        commit("updateStatus", "success");
        return _setRef();
      } else {
        // console.log('Create user profile')
        const profile = {
          displayName: state.user.displayName || state.nickname,
          email: state.user.email,
          uid: state.user.uid,
          photoURL: state.user.photoURL,
          location: "",
          bio: "",
          website: "",
          anonymous: state.user.isAnonymous,
          send_stats: true,
          receive_notifications: false
        };
        userRef
          .set(profile, {
            merge: true
          })
          .then(function() {
            commit("updateUserProfile", profile);
            commit("updateStatus", "success");
            return _setRef();
          });
      }
    })
    .catch(function(error) {
      // console.log("Some error occurred in user profile");
      commit("updateStatus", "error");
      commit("updateError", error.message);

      // console.log(error);
    });
}

export function sessionLogin({ commit, dispatch, state }, user) {
  commit("updateError", null);
  commit("updateStatus", "success");
  if (user.anonymous) {
    commit("updateUser", {
      displayName: state.nickname || "Anonymous",
      ...user
    });
  } else {
    commit("updateUser", user);
  }

  if (!state.userProfile || user.uid != state.userProfile.uid)
    dispatch("loadUserProfile", user);
}

export function resetUser({ commit, dispatch }) {
  commit("updateStatus", "success");
  commit("updateUser", null);
  commit("updateUserProfile", null);
}
